@@ -1,7 +1,7 @@
 package Tree::To::Text;
 
-our $DATE = '2020-04-14'; # DATE
-our $VERSION = '0.060'; # VERSION
+our $DATE = '2021-05-06'; # DATE
+our $VERSION = '0.061'; # VERSION
 
 1;
 # ABSTRACT: Show a tree object structure as text
@@ -18,7 +18,7 @@ Tree::To::Text - Show a tree object structure as text
 
 =head1 VERSION
 
-This document describes version 0.060 of Tree::To::Text (from Perl distribution Tree-To-Text), released on 2020-04-14.
+This document describes version 0.061 of Tree::To::Text (from Perl distribution Tree-To-Text), released on 2021-05-06.
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ Source repository is at L<https://github.com/perlancar/perl-Tree-To-Text>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-To-Text>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Tree-To-Text/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -55,7 +55,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
